@@ -2,18 +2,11 @@
 
 """Testing :mod:`astropy.cosmology.flrw.lambdacdm`."""
 
-##############################################################################
-# IMPORTS
-
-# STDLIB
-
-# THIRD PARTY
 import pathlib
 
 import numpy as np
 import pytest
 
-# LOCAL
 import astropy.constants as const
 import astropy.cosmology.units as cu
 import astropy.units as u
@@ -64,7 +57,7 @@ class TestLambdaCDM(FLRWTest):
 
     @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
     @pytest.mark.parametrize("z, exc", invalid_zs)
-    @pytest.mark.parametrize("method", _FLRW_redshift_methods)
+    @pytest.mark.parametrize("method", sorted(_FLRW_redshift_methods))
     def test_redshift_method_bad_input(self, cosmo, method, z, exc):
         """Test all the redshift methods for bad input."""
         super().test_redshift_method_bad_input(cosmo, method, z, exc)
@@ -77,16 +70,20 @@ class TestLambdaCDM(FLRWTest):
         w = cosmo.w(z)
         assert u.allclose(w, -1.0)
 
-    def test_repr(self, cosmo_cls, cosmo):
+    def test_repr(self, cosmo):
         """Test method ``.__repr__()``."""
-        super().test_repr(cosmo_cls, cosmo)
+        assert repr(cosmo) == (
+            "LambdaCDM(name='ABCMeta', H0=<Quantity 70. km / (Mpc s)>, Om0=0.27,"
+            " Ode0=0.73, Tcmb0=<Quantity 3. K>, Neff=3.04,"
+            " m_nu=<Quantity [0., 0., 0.] eV>, Ob0=0.03)"
+        )
 
-        expected = (
-            'LambdaCDM(name="ABCMeta", H0=70.0 km / (Mpc s), Om0=0.27,'
-            " Ode0=0.73, Tcmb0=3.0 K, Neff=3.04, m_nu=[0. 0. 0.] eV,"
-            " Ob0=0.03)"
+    def test_str(self, cosmo):
+        """Test method ``.__str__()``."""
+        assert str(cosmo) == (
+            'LambdaCDM(name="ABCMeta", H0=70.0 km / (Mpc s), Om0=0.27, Ode0=0.73,'
+            " Tcmb0=3.0 K, Neff=3.04, m_nu=[0. 0. 0.] eV, Ob0=0.03)"
         )
-        assert repr(cosmo) == expected
 
     @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
     @pytest.mark.parametrize(
@@ -131,7 +128,9 @@ class TestFlatLambdaCDM(FlatFLRWMixinTest, TestLambdaCDM):
 
     @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
     @pytest.mark.parametrize("z, exc", invalid_zs)
-    @pytest.mark.parametrize("method", TestLambdaCDM._FLRW_redshift_methods - {"Otot"})
+    @pytest.mark.parametrize(
+        "method", sorted(TestLambdaCDM._FLRW_redshift_methods - {"Otot"})
+    )
     def test_redshift_method_bad_input(self, cosmo, method, z, exc):
         """Test all the redshift methods for bad input."""
         super().test_redshift_method_bad_input(cosmo, method, z, exc)
@@ -139,16 +138,20 @@ class TestFlatLambdaCDM(FlatFLRWMixinTest, TestLambdaCDM):
     # ===============================================================
     # Method & Attribute Tests
 
-    def test_repr(self, cosmo_cls, cosmo):
+    def test_repr(self, cosmo):
         """Test method ``.__repr__()``."""
-        super().test_repr(cosmo_cls, cosmo)
-
-        expected = (
-            'FlatLambdaCDM(name="ABCMeta", H0=70.0 km / (Mpc s),'
-            " Om0=0.27, Tcmb0=3.0 K, Neff=3.04, m_nu=[0. 0. 0.] eV,"
+        assert repr(cosmo) == (
+            "FlatLambdaCDM(name='ABCMeta', H0=<Quantity 70. km / (Mpc s)>, Om0=0.27,"
+            " Tcmb0=<Quantity 3. K>, Neff=3.04, m_nu=<Quantity [0., 0., 0.] eV>,"
             " Ob0=0.03)"
         )
-        assert repr(cosmo) == expected
+
+    def test_str(self, cosmo):
+        """Test method ``.__str__()``."""
+        assert str(cosmo) == (
+            'FlatLambdaCDM(name="ABCMeta", H0=70.0 km / (Mpc s), Om0=0.27, '
+            "Tcmb0=3.0 K, Neff=3.04, m_nu=[0. 0. 0.] eV, Ob0=0.03)"
+        )
 
     # ===============================================================
     # Usage Tests
@@ -953,16 +956,16 @@ def test_age_in_special_cosmologies():
     Some analytic solutions fail at these critical points.
     """
     c_dS = FlatLambdaCDM(100, 0, Tcmb0=0)
-    assert u.allclose(c_dS.age(z=0), np.inf * u.Gyr)
-    assert u.allclose(c_dS.age(z=1), np.inf * u.Gyr)
-    assert u.allclose(c_dS.lookback_time(z=0), 0 * u.Gyr)
-    assert u.allclose(c_dS.lookback_time(z=1), 6.777539216261741 * u.Gyr)
+    assert u.allclose(c_dS.age(0), np.inf * u.Gyr)
+    assert u.allclose(c_dS.age(1), np.inf * u.Gyr)
+    assert u.allclose(c_dS.lookback_time(0), 0 * u.Gyr)
+    assert u.allclose(c_dS.lookback_time(1), 6.777539216261741 * u.Gyr)
 
     c_EdS = FlatLambdaCDM(100, 1, Tcmb0=0)
-    assert u.allclose(c_EdS.age(z=0), 6.518614811154189 * u.Gyr)
-    assert u.allclose(c_EdS.age(z=1), 2.3046783684542738 * u.Gyr)
-    assert u.allclose(c_EdS.lookback_time(z=0), 0 * u.Gyr)
-    assert u.allclose(c_EdS.lookback_time(z=1), 4.213936442699092 * u.Gyr)
+    assert u.allclose(c_EdS.age(0), 6.518614811154189 * u.Gyr)
+    assert u.allclose(c_EdS.age(1), 2.3046783684542738 * u.Gyr)
+    assert u.allclose(c_EdS.lookback_time(0), 0 * u.Gyr)
+    assert u.allclose(c_EdS.lookback_time(1), 4.213936442699092 * u.Gyr)
 
 
 @pytest.mark.skipif(not HAS_SCIPY, reason="test requires scipy")
@@ -972,20 +975,20 @@ def test_distance_in_special_cosmologies():
     Some analytic solutions fail at these critical points.
     """
     c_dS = FlatLambdaCDM(100, 0, Tcmb0=0)
-    assert u.allclose(c_dS.comoving_distance(z=0), 0 * u.Mpc)
-    assert u.allclose(c_dS.comoving_distance(z=1), 2997.92458 * u.Mpc)
+    assert u.allclose(c_dS.comoving_distance(0), 0 * u.Mpc)
+    assert u.allclose(c_dS.comoving_distance(1), 2997.92458 * u.Mpc)
 
     c_EdS = FlatLambdaCDM(100, 1, Tcmb0=0)
-    assert u.allclose(c_EdS.comoving_distance(z=0), 0 * u.Mpc)
-    assert u.allclose(c_EdS.comoving_distance(z=1), 1756.1435599923348 * u.Mpc)
+    assert u.allclose(c_EdS.comoving_distance(0), 0 * u.Mpc)
+    assert u.allclose(c_EdS.comoving_distance(1), 1756.1435599923348 * u.Mpc)
 
     c_dS = LambdaCDM(100, 0, 1, Tcmb0=0)
-    assert u.allclose(c_dS.comoving_distance(z=0), 0 * u.Mpc)
-    assert u.allclose(c_dS.comoving_distance(z=1), 2997.92458 * u.Mpc)
+    assert u.allclose(c_dS.comoving_distance(0), 0 * u.Mpc)
+    assert u.allclose(c_dS.comoving_distance(1), 2997.92458 * u.Mpc)
 
     c_EdS = LambdaCDM(100, 1, 0, Tcmb0=0)
-    assert u.allclose(c_EdS.comoving_distance(z=0), 0 * u.Mpc)
-    assert u.allclose(c_EdS.comoving_distance(z=1), 1756.1435599923348 * u.Mpc)
+    assert u.allclose(c_EdS.comoving_distance(0), 0 * u.Mpc)
+    assert u.allclose(c_EdS.comoving_distance(1), 1756.1435599923348 * u.Mpc)
 
 
 @pytest.mark.skipif(not HAS_SCIPY, reason="test requires scipy")
