@@ -21,13 +21,12 @@ from astropy.io.fits.column import (
     python_to_tdisp,
 )
 from astropy.io.tests.mixin_columns import compare_attrs, mixin_cols, serialized_names
-from astropy.table import Column, QTable, Table
+from astropy.table import Column, MaskedColumn, QTable, Table
 from astropy.table.table_helpers import simple_table
 from astropy.time import Time
+from astropy.units import UnitScaleError
 from astropy.units import allclose as quantity_allclose
-from astropy.units.format.fits import UnitScaleError
 from astropy.units.quantity import QuantityInfo
-from astropy.utils.compat import NUMPY_LT_1_22
 from astropy.utils.data import get_pkg_data_filename
 from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyUserWarning
 from astropy.utils.misc import _NOT_OVERWRITING_MSG_MATCH
@@ -179,7 +178,7 @@ class TestSingleTable:
         hdu = BinTableHDU(self.data)
         hdu.columns[0].unit = "Angstroms"
         hdu.columns[2].unit = "ergs/(cm.s.Angstroms)"
-        with u.set_enabled_aliases(dict(Angstroms=u.AA, ergs=u.erg)):
+        with u.set_enabled_aliases({"Angstroms": u.AA, "ergs": u.erg}):
             t = table_type.read(hdu)
         assert t["a"].unit == u.AA
         assert t["c"].unit == u.erg / (u.cm * u.s * u.AA)
@@ -712,6 +711,9 @@ def test_scale_error():
     [
         ("EN10.5", ("EN", "10", "5", None)),
         ("F6.2", ("F", "6", "2", None)),
+        ("F12.10", ("F", "12", "10", None)),
+        ("ES12.11", ("ES", "12", "11", None)),
+        ("EN12.11", ("EN", "12", "11", None)),
         ("B5.10", ("B", "5", "10", None)),
         ("E10.5E3", ("E", "10", "5", "3")),
         ("A21", ("A", "21", None, None)),
@@ -764,7 +766,7 @@ def test_bool_column(tmp_path):
     """
 
     arr = np.ones(5, dtype=bool)
-    arr[::2] == np.False_
+    arr[::2] = False
 
     t = Table([arr])
     t.write(tmp_path / "test.fits", overwrite=True)
@@ -876,11 +878,7 @@ def assert_objects_equal(obj1, obj2, attrs, compare_class=True):
             # FITS does not perfectly preserve dtype: byte order can change, and
             # unicode gets stored as bytes.  So, we just check safe casting, to
             # ensure we do not, e.g., accidentally change integer to float, etc.
-            if NUMPY_LT_1_22 and a1.names:
-                # For old numpy, can_cast does not deal well with structured dtype.
-                assert a1.names == a2.names
-            else:
-                assert np.can_cast(a2, a1, casting="safe")
+            assert np.can_cast(a2, a1, casting="safe")
         else:
             assert np.all(a1 == a2)
 
@@ -1069,3 +1067,63 @@ def test_meta_not_modified(tmp_path):
 def test_is_fits_gh_14305():
     """Regression test for https://github.com/astropy/astropy/issues/14305"""
     assert not connect.is_fits("", "foo.bar", None)
+
+
+def test_keep_masked_state_integer_columns(tmp_path):
+    """Regression test for https://github.com/astropy/astropy/issues/15417"""
+    filename = tmp_path / "test_masked.fits"
+    t = Table([[1, 2], [1.5, 2.5]], names=["a", "b"])
+    t["c"] = MaskedColumn([1, 2], mask=[True, False])
+    t.write(filename)
+    tr = Table.read(filename)
+    assert not isinstance(tr["a"], MaskedColumn)
+    assert not isinstance(tr["b"], MaskedColumn)
+    assert isinstance(tr["c"], MaskedColumn)
+
+
+def test_null_propagation_in_table_read(tmp_path):
+    """Checks that integer columns with a TNULL value set (e.g. masked columns)
+    have their TNULL value propagated when being read in by Table.read"""
+
+    # Could be anything except for 999999, which is the "default" fill_value
+    # for masked int arrays
+    NULL_VALUE = -1
+
+    output_filename = tmp_path / "null_table.fits"
+
+    data = np.asarray([1, 2, NULL_VALUE, 4], dtype=np.int32)
+
+    # Create table with BinTableHDU, with integer column containing a custom null
+    c = fits.Column(name="a", array=data, null=NULL_VALUE, format="J")
+    hdu = BinTableHDU.from_columns([c])
+    hdu.writeto(output_filename)
+
+    # Read the table in with Table.read, and ensure the column's fill_value is
+    # equal to NULL_VALUE
+    t = Table.read(output_filename)
+    assert t["a"].fill_value == NULL_VALUE
+
+
+def test_unsigned_int_dtype_propagation_for_zero_length_table():
+    # Regression test for gh-16501
+    tbl = Table(
+        [
+            Column(name="unsigned16", dtype="uint16"),
+            Column(name="unsigned32", dtype="uint32"),
+            Column(name="unsigned64", dtype="uint64"),
+        ]
+    )
+    hdu = BinTableHDU(tbl)
+    tbl2 = Table.read(hdu)
+    assert tbl.dtype == tbl2.dtype
+
+
+@pytest.mark.parametrize("table_type", [Table, QTable])
+def test_zero_length_string_columns_can_be_read_into_table(table_type, tmp_path):
+    filename = tmp_path / "zerodtable.fits"
+    data = np.array([("", 12)], dtype=[("a", "S"), ("b", "i4")])
+    hdu = fits.BinTableHDU(data)
+    hdu.writeto(filename)
+    t = table_type.read(filename)
+    assert t["a"].dtype.itemsize == 0
+    assert t["a"].dtype == data["a"].dtype
