@@ -3,7 +3,6 @@
 import itertools
 import warnings
 import weakref
-from collections import OrderedDict
 from copy import deepcopy
 
 import numpy as np
@@ -397,7 +396,7 @@ class ColumnInfo(BaseColumnInfo):
         else:
             units = [None] * len(names)
         for name, part_unit in zip(names, units):
-            part = Column(self._parent[name])
+            part = self._parent.__class__(self._parent[name])
             part.unit = part_unit
             part.description = None
             part.meta = {}
@@ -504,9 +503,7 @@ class ColumnInfo(BaseColumnInfo):
 
 
 class BaseColumn(_ColumnGetitemShim, np.ndarray):
-    meta = MetaData(default_factory=OrderedDict)
-    # It's important that the metadata is an OrderedDict so that the order of
-    # the metadata is preserved when the column is YAML serialized.
+    meta = MetaData(default_factory=dict)
 
     def __new__(
         cls,
@@ -855,7 +852,7 @@ class BaseColumn(_ColumnGetitemShim, np.ndarray):
 
     def pformat(
         self,
-        max_lines=None,
+        max_lines=-1,
         show_name=True,
         show_unit=False,
         show_dtype=False,
@@ -863,17 +860,19 @@ class BaseColumn(_ColumnGetitemShim, np.ndarray):
     ):
         """Return a list of formatted string representation of column values.
 
-        If no value of ``max_lines`` is supplied then the height of the
+        If ``max_lines=None`` is supplied then the height of the
         screen terminal is used to set ``max_lines``.  If the terminal
         height cannot be determined then the default will be
         determined using the ``astropy.conf.max_lines`` configuration
         item. If a negative value of ``max_lines`` is supplied then
-        there is no line limit applied.
+        there is no line limit applied (default).
 
         Parameters
         ----------
-        max_lines : int
-            Maximum lines of output (header + data rows)
+        max_lines : int or None
+            Maximum lines of output (header + data rows).
+            -1 (default) implies no limit, ``None`` implies using the
+            height of the current terminal.
 
         show_name : bool
             Include column name. Default is True.
@@ -907,7 +906,7 @@ class BaseColumn(_ColumnGetitemShim, np.ndarray):
     def pprint(self, max_lines=None, show_name=True, show_unit=False, show_dtype=False):
         """Print a formatted string representation of column values.
 
-        If no value of ``max_lines`` is supplied then the height of the
+        If ``max_lines=None`` (default) then the height of the
         screen terminal is used to set ``max_lines``.  If the terminal
         height cannot be determined then the default will be
         determined using the ``astropy.conf.max_lines`` configuration
